# Copyright (C) 2011 Oracle. All rights reserved.
# 
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, version 2.  This program is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
# Public License for more details.  You should have received a copy of the GNU
# General Public License along with this program; if not, write to the Free
# Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 021110-1307, USA.

'''Nephos global configuration loader'''

import sys
import os.path
import operator
import ConfigParser

def _find_qbase():
    '''Try to discover the on-disk location of the QBase sandbox'''
    if 'QBASE' in os.environ:
        return os.environ['QBASE']

    potential_qshell = os.path.abspath(os.path.dirname(
                                        os.path.dirname(sys.executable)))
    if os.path.exists(os.path.join(potential_qshell, 'qshell')):
        return potential_qshell

    if os.path.exists(os.path.join('/opt', 'qbase3', 'qshell')):
        return os.path.join('/opt', 'qbase3')

    return None


class NephosConfig(object): #pylint: disable-msg=R0903
    '''Nephos configuration holder'''
    def __init__(self):
        self._machineid = self._load_machineid()

    @staticmethod
    def _load_machineid():
        '''Load the ID of the machine this process runs on'''
        qbase = _find_qbase()
        if not qbase:
            raise RuntimeError('Unable to locate QBASE')

        nephos_config_path = os.path.join(qbase, 'cfg', 'qconfig', 'localnode.cfg')
        if not os.path.exists(nephos_config_path):
            raise RuntimeError('Nephos configuration file %s not found' % \
                               nephos_config_path)

        parser = ConfigParser.SafeConfigParser()
        parser.read(nephos_config_path)

        return parser.get('main', 'machineguid')

    machineid = property(fget=operator.attrgetter('_machineid'),
                         doc='Nephos ID of this machine')

# Create instance and delete class
config = NephosConfig() #pylint: disable-msg=C0103
del NephosConfig
