# Copyright (C) 2011 Oracle. All rights reserved.
# 
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, version 2.  This program is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
# Public License for more details.  You should have received a copy of the GNU
# General Public License along with this program; if not, write to the Free
# Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 021110-1307, USA.

import os.path

from zope.interface import implements

from twisted.python import usage
from twisted.plugin import IPlugin
from twisted.application.service import IServiceMaker

import monitor
from monitor.service import Monitor

class Options(usage.Options):
    optParameters = [['config', 'c', None, 'Service config file']]

    def postOptions(self):
        if self['config']:
            if not os.path.isfile(self['config']):
                raise usage.UsageError('no such file "%s"' % self['config'])

        else:
            config = monitor.DEFAULT_CONFIG
            if not os.path.isfile(config):
                raise usage.UsageError(
                    'no config file given, and default "%s" doesn\'t exist' % \
                    config)
            else:
                self['config'] = config


class MonitorServiceMaker(object):
    implements(IServiceMaker, IPlugin)
    tapname = 'monitor'
    description = 'Nephos monitor service'
    options = Options

    def makeService(self, options):
        '''Return the monitor service'''
        return Monitor(options['config'])

serviceMaker = MonitorServiceMaker()
